@@ -1,7 +1,9 @@
 from .bot import *
 from .client import *
-from .comments import *
+from .comment import *
 from .core import *
+from .errors import *
 from .loop_manager import *
 from .server import *
+from .tags import *
 from .user import *
